import { FormattedMessage, useIntl } from 'react-intl';
import { Form, Field } from 'react-final-form';

import { useSubmitForm, validatorsWithMessage, composeValidators, translate } from 'modules/form';

import { login } from '../services/actions';
import { LoginFormField } from '../types';

const { required, email } = validatorsWithMessage;

const validators = {
    [LoginFormField.EMAIL]: composeValidators(required, email),
    [LoginFormField.PASSWORD]: required,
};

const LoginForm = () => {
    const { formatMessage } = useIntl();
    const onSubmit = useSubmitForm(login);

    return (
        <Form
            onSubmit={onSubmit}
            render={({ handleSubmit, submitError }) => (
                <form onSubmit={handleSubmit}>
                    <div>
                        <label>
                            <FormattedMessage id="login.email" />
                        </label>
                        <Field
                            name={LoginFormField.EMAIL}
                            type="email"
                            component="input"
                            validate={translate(formatMessage, validators[LoginFormField.EMAIL])}
                        />
                    </div>

                    <div>
                        <label>
                            <FormattedMessage id="login.password" />
                        </label>
                        <Field
                            name={LoginFormField.PASSWORD}
                            type="password"
                            component="input"
                            validate={translate(formatMessage, validators[LoginFormField.PASSWORD])}
                        />
                    </div>

                    <button type="submit">
                        <FormattedMessage id="login.submit" />
                    </button>

                    {submitError && <p>{submitError}</p>}
                </form>
            )}
        />
    );
};

export default LoginForm;
