import { composeValidators, translate } from '../helpers';
import { required, email } from '../validatorsWithMessage';

describe('Form validator helpers', () => {
    let formatMessage;

    beforeEach(() => {
        formatMessage = jest.fn(({ id }) => id);
    });

    describe('composeValidators', () => {
        it('returns no error if field valid', () => {
            const validate = composeValidators(required, email);

            expect(validate('test@gmail.com')).toBeUndefined();
        });

        it('returns first validation error', () => {
            const validate = composeValidators(required, email);

            expect(validate('')).toBe('error.form.required');
        });

        it('returns second validation error', () => {
            const validate = composeValidators(required, email);

            expect(validate('test')).toBe('error.form.email');
        });
    });

    describe('translate', () => {
        it('translates message from single validator', () => {
            const validate = translate(formatMessage, required);

            expect(validate('')).toBe('error.form.required');
            expect(formatMessage).toHaveBeenCalledWith({ id: 'error.form.required' });
        });

        it('translates message from composed validator', () => {
            const validate = translate(formatMessage, composeValidators(required, email));

            expect(validate('test')).toBe('error.form.email');
            expect(formatMessage).toHaveBeenCalledWith({ id: 'error.form.email' });
        });

        it('returns undefined for valid values', () => {
            const validate = translate(formatMessage, email);

            expect(validate('test@gmail.com')).toBeUndefined();
            expect(formatMessage).not.toHaveBeenCalled();
        });
    });
});
